==> adams-heatmap-0.4.2-sources.jar: adams/gui/chooser/HeatmapFileChooser.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * HeatmapFileChooser.java
 * Copyright (C) 2011-2012 University of Waikato, Hamilton, New Zealand
 */

package adams.gui.chooser;

import java.io.File;
import java.util.Vector;

import adams.data.heatmap.Heatmap;
import adams.data.io.input.AbstractDataContainerReader;
import adams.data.io.input.AbstractHeatmapReader;
import adams.data.io.output.AbstractDataContainerWriter;
import adams.data.io.output.AbstractHeatmapWriter;

import com.googlecode.vfsjfilechooser2.utils.VFSUtils;

/**
 * A specialized JFileChooser that lists all available file Readers and Writers
 * for heatmaps.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 6166 $
 */
public class HeatmapFileChooser
  extends AbstractDataContainerFileChooser<Heatmap> {

  /** for serialization. */
  private static final long serialVersionUID = -5373058011025481738L;

  /**
   * Constructs a FileChooser pointing to the user's default directory.
   */
  public HeatmapFileChooser() {
    super();
  }

  /**
   * Constructs a FileChooser using the given File as the path.
   *
   * @param currentDirectory	the path to start in
   */
  public HeatmapFileChooser(File currentDirectory) {
    super(currentDirectory);
  }

  /**
   * Constructs a FileChooser using the given path.
   *
   * @param currentDirectory	the path to start in
   */
  public HeatmapFileChooser(String currentDirectory) {
    super(currentDirectory);
  }

  /**
   * Returns the default reader.
   *
   * @return		the default reader
   */
  @Override
  protected AbstractDataContainerReader<Heatmap> getDefaultReader() {
    return new adams.data.io.input.FloatMatrixHeatmapReader();
  }

  /**
   * Returns the default writer.
   *
   * @return		the default writer
   */
  @Override
  protected AbstractDataContainerWriter<Heatmap> getDefaultWriter() {
    return new adams.data.io.output.FloatMatrixHeatmapWriter();
  }

  /**
   * Performs the actual initialization of the filters.
   */
  @Override
  protected void doInitializeFilters() {
    initFilters(this, true, AbstractHeatmapReader.getReaders());
    initFilters(this, false, AbstractHeatmapWriter.getWriters());
  }

  /**
   * Returns the reader for the specified file.
   *
   * @param file	the file to determine a reader for
   * @return		the reader, null if none found
   */
  public AbstractDataContainerReader<Heatmap> getReaderForFile(File file) {
    AbstractDataContainerReader	result;

    result = null;

    for (Vector<DataContainerFileExtensionFilter> list: m_ReaderFileFilters.values()) {
      for (DataContainerFileExtensionFilter filter: list) {
	// TODO: handling of *.* filters?
	if (filter.accept(VFSUtils.toFileObject(file))) {
	  try {
	    result = (AbstractDataContainerReader<Heatmap>) Class.forName(filter.getClassname()).newInstance();
	  }
	  catch (Exception e) {
	    System.err.println("Failed to instantiate reader '" + filter.getClassname() + "':");
	    e.printStackTrace();
	  }
	}
      }
    }

    return result;
  }

  /**
   * Returns the writer for the specified file.
   *
   * @param file	the file to determine a reader for
   * @return		the writer, null if none found
   */
  public AbstractDataContainerWriter<Heatmap> getWriterForFile(File file) {
    AbstractDataContainerWriter<Heatmap>	result;

    result = null;

    for (Vector<DataContainerFileExtensionFilter> list: m_WriterFileFilters.values()) {
      for (DataContainerFileExtensionFilter filter: list) {
	// TODO: handling of *.* filters?
	if (filter.accept(VFSUtils.toFileObject(file))) {
	  try {
	    result = (AbstractDataContainerWriter<Heatmap>) Class.forName(filter.getClassname()).newInstance();
	  }
	  catch (Exception e) {
	    System.err.println("Failed to instantiate writer '" + filter.getClassname() + "':");
	    e.printStackTrace();
	  }
	}
      }
    }

    return result;
  }
}

==> adams-heatmap-0.4.4-sources.jar: adams/gui/chooser/HeatmapFileChooser.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * HeatmapFileChooser.java
 * Copyright (C) 2011-2013 University of Waikato, Hamilton, New Zealand
 */

package adams.gui.chooser;

import java.io.File;
import java.util.List;

import adams.data.heatmap.Heatmap;
import adams.data.io.input.AbstractDataContainerReader;
import adams.data.io.input.AbstractHeatmapReader;
import adams.data.io.output.AbstractDataContainerWriter;
import adams.data.io.output.AbstractHeatmapWriter;

/**
 * A specialized JFileChooser that lists all available file Readers and Writers
 * for heatmaps.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 7570 $
 */
public class HeatmapFileChooser
  extends AbstractDataContainerFileChooser<Heatmap, AbstractDataContainerReader<Heatmap>, AbstractDataContainerWriter<Heatmap>> {

  /** for serialization. */
  private static final long serialVersionUID = -5373058011025481738L;

  /**
   * Constructs a FileChooser pointing to the user's default directory.
   */
  public HeatmapFileChooser() {
    super();
  }

  /**
   * Constructs a FileChooser using the given File as the path.
   *
   * @param currentDirectory	the path to start in
   */
  public HeatmapFileChooser(File currentDirectory) {
    super(currentDirectory);
  }

  /**
   * Constructs a FileChooser using the given path.
   *
   * @param currentDirectory	the path to start in
   */
  public HeatmapFileChooser(String currentDirectory) {
    super(currentDirectory);
  }

  /**
   * Returns the default reader.
   *
   * @return		the default reader
   */
  @Override
  protected AbstractDataContainerReader<Heatmap> getDefaultReader() {
    return new adams.data.io.input.FloatMatrixHeatmapReader();
  }

  /**
   * Returns the default writer.
   *
   * @return		the default writer
   */
  @Override
  protected AbstractDataContainerWriter<Heatmap> getDefaultWriter() {
    return new adams.data.io.output.FloatMatrixHeatmapWriter();
  }

  /**
   * Returns the reader superclass for the GOE.
   *
   * @return		the reader class
   */
  @Override
  protected Class getReaderClass() {
    return AbstractHeatmapReader.class;
  }

  /**
   * Returns the writer superclass for the GOE.
   *
   * @return		the writer class
   */
  @Override
  protected Class getWriterClass() {
    return AbstractHeatmapWriter.class;
  }

  /**
   * Performs the actual initialization of the filters.
   */
  @Override
  protected void doInitializeFilters() {
    initFilters(this, true, AbstractHeatmapReader.getReaders());
    initFilters(this, false, AbstractHeatmapWriter.getWriters());
  }

  /**
   * Returns the reader for the specified file.
   *
   * @param file	the file to determine a reader for
   * @return		the reader, null if none found
   */
  public AbstractDataContainerReader<Heatmap> getReaderForFile(File file) {
    AbstractDataContainerReader	result;

    result = null;

    for (List<ExtensionFileFilterWithClass> list: m_ReaderFileFilters.values()) {
      for (ExtensionFileFilterWithClass filter: list) {
	// TODO: handling of *.* filters?
	if (filter.accept(file)) {
	  try {
	    result = (AbstractDataContainerReader<Heatmap>) Class.forName(filter.getClassname()).newInstance();
	  }
	  catch (Exception e) {
	    System.err.println("Failed to instantiate reader '" + filter.getClassname() + "':");
	    e.printStackTrace();
	  }
	}
      }
    }

    return result;
  }

  /**
   * Returns the writer for the specified file.
   *
   * @param file	the file to determine a reader for
   * @return		the writer, null if none found
   */
  public AbstractDataContainerWriter<Heatmap> getWriterForFile(File file) {
    AbstractDataContainerWriter<Heatmap>	result;

    result = null;

    for (List<ExtensionFileFilterWithClass> list: m_WriterFileFilters.values()) {
      for (ExtensionFileFilterWithClass filter: list) {
	// TODO: handling of *.* filters?
	if (filter.accept(file)) {
	  try {
	    result = (AbstractDataContainerWriter<Heatmap>) Class.forName(filter.getClassname()).newInstance();
	  }
	  catch (Exception e) {
	    System.err.println("Failed to instantiate writer '" + filter.getClassname() + "':");
	    e.printStackTrace();
	  }
	}
      }
    }

    return result;
  }
}
